==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/GridColumnOptionsSimpleSectionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsSimpleSectionBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsSimpleSectionBaseDescriptionMetadata, _super);
    function GridColumnOptionsSimpleSectionBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a == null) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
        }
        if (a.k(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a)) {
            return;
        }
        a.ab(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
    };
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c = function (a) {
        GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
        a.item("Caption", "String");
        a.item("ShowCaption", "Boolean");
    };
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.d = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.b(a);
        a.ac("GridColumnOptionsSimpleSectionBase", GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
    };
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.$t = markType(GridColumnOptionsSimpleSectionBaseDescriptionMetadata, 'GridColumnOptionsSimpleSectionBaseDescriptionMetadata');
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a = null;
    return GridColumnOptionsSimpleSectionBaseDescriptionMetadata;
}(Base));
export { GridColumnOptionsSimpleSectionBaseDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/GridColumnOptionsSimpleSectionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsSimpleSectionBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsSimpleSectionBaseDescriptionMetadata, _super);
    function GridColumnOptionsSimpleSectionBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a == null) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
        }
        if (a.k(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
    };
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c = function (a) {
        GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
        a.item("Caption", "String");
        a.item("ShowCaption", "Boolean");
    };
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.d = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.b(a);
        a.ad("GridColumnOptionsSimpleSectionBase", GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
    };
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.$t = markType(GridColumnOptionsSimpleSectionBaseDescriptionMetadata, 'GridColumnOptionsSimpleSectionBaseDescriptionMetadata');
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a = null;
    return GridColumnOptionsSimpleSectionBaseDescriptionMetadata;
}(Base));
export { GridColumnOptionsSimpleSectionBaseDescriptionMetadata };
